@@ -1,7 +1,9 @@
+from typing import Tuple
 from datetime import datetime
 
-def resolve_date(year: str, month: str, date: datetime) -> (str, str):
-    """Private method that resolves different date parameters 
+
+def resolve_date(year: str, month: str, date: datetime) -> Tuple[str, str]:
+    """Private method that resolves different date parameters
     and returns 'yyyy' and 'mm'.
 
     Parameters:
@@ -11,7 +13,9 @@ def resolve_date(year: str, month: str, date: datetime) -> (str, str):
     """
 
     if (year is None) != (month is None):
-        raise ValueError("You must provide both the year and the month, or a datetime.datetime object")
+        raise ValueError(
+            "You must provide both the year and the month, or a datetime.datetime object"
+        )
     if year is not None:
         if isinstance(year, int):
             year = str(year)
@@ -21,5 +25,6 @@ def resolve_date(year: str, month: str, date: datetime) -> (str, str):
     elif date is not None:
         return str(date.year), str(date.month).zfill(2)
     else:
-        raise ValueError("You must provide both the year and the month, or a datetime.datetime object")
-
+        raise ValueError(
+            "You must provide both the year and the month, or a datetime.datetime object"
+        )
